package com.inet.application.embedded;

import com.inet.file.CombinedFileDescription;
import com.inet.file.FileCombiner.CombinedFile;
import com.inet.plugin.PluginInfo;
import com.inet.plugin.ServerPlugin;
import com.inet.plugin.ServerPluginManager;
import com.inet.remote.gui.RemoteGuiServerPlugin;
import com.inet.remote.gui.angular.RemoteAngularThemeService;
import com.inet.shared.plugins.theme.server.ThemeResource;

@PluginInfo( //
                id = "application.embedded", //
                flags = "core", packages = "", //
                dependencies = "remotegui", //
                optionalDependencies = "theme", //
                icon = "com/inet/application/embedded/embeddeded_48.png", //
                group = "samples", //
                version = ServerPlugin.CORE_VERSION //
)
/**
 * Plugin to have the whole interface embedded into another web page. That is: Remove the header.
 */
public class EmbeddedServerPlugin implements ServerPlugin {

    /**
     * {@inheritDoc}
     */
    @Override
    public void registerExtension( ServerPluginManager spm ) {
        // register optional additional java script
        CombinedFile combinedFile = new CombinedFile( "application/x-javascript; charset=utf-8" );
        // add at least one javascript resource
        combinedFile.add( getClass(), "webgui/embeddedMode.js" );
        spm.register( CombinedFileDescription.class, new CombinedFileDescription( RemoteGuiServerPlugin.APP_KEY, 10000, "remotegui.lib.js", combinedFile ) );

        // add styles - uncompiled
        if( spm.isPluginLoaded( "theme" ) ) {
            spm.register( ThemeResource.class, new ThemeResource( 100, RemoteAngularThemeService.THEME_APP_KEY, getClass().getResource( "webgui/embeddedMode.less" ) ) );
        }

        // add styles - precompiled
        final CombinedFile css = new CombinedFile( "text/css; charset=utf-8" );
        css.add( getClass(), "webgui/embeddedMode.css" );
        spm.register( CombinedFileDescription.class, new CombinedFileDescription( RemoteGuiServerPlugin.APP_KEY, 100, "defaulttheme.css", css ) );
    }

    /**
     * {@inheritDoc}
     */
    @Override
    public void init( ServerPluginManager spm ) {
        // nothing
    }

    /**
     * {@inheritDoc}
     */
    @Override
    public void reset() {
        // nothing
    }

    /**
     * {@inheritDoc}
     */
    @Override
    public void restart() {
        // nothing
    }

}
